</TABLE>

<P><B>For next month</B>

<P>Discussion about this analysis continues on the
<A href="http://dtype.org/mailman/listinfo/keyanalyze-discuss">keyanalyze-discuss</A>
mailing list.

<P>If you have any suggestions, please send them my way, especially if
you have the algorithms as well.
If you're so inclined, please
<A href="code.php">have a look</A> at the code as well.

<?php
html_bottom();
?> 
